pub fn relation(a: &str, b: &str) -> Option<String>
Three-valued temporal relation between a and b as a JSON string, or undefined if either input is invalid. See RelationSummary for the object shape.
a
b
undefined
RelationSummary